summaryrefslogtreecommitdiffstats
path: root/kfile-plugins/torrent/bint.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:48:06 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:48:06 +0000
commit47c8a359c5276062c4bc17f0e82410f29081b502 (patch)
tree2d54a5f60a5b74067632f9ef6df58c2bc38155e6 /kfile-plugins/torrent/bint.h
parent6f82532777a35e0e60bbd2b290b2e93e646f349b (diff)
downloadtdenetwork-47c8a359c5276062c4bc17f0e82410f29081b502.tar.gz
tdenetwork-47c8a359c5276062c4bc17f0e82410f29081b502.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1157648 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kfile-plugins/torrent/bint.h')
-rw-r--r--kfile-plugins/torrent/bint.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kfile-plugins/torrent/bint.h b/kfile-plugins/torrent/bint.h
index 02875bad..7e1fc582 100644
--- a/kfile-plugins/torrent/bint.h
+++ b/kfile-plugins/torrent/bint.h
@@ -19,7 +19,7 @@
#ifndef _BINT_H
#define _BINT_H
-#include <qcstring.h>
+#include <tqcstring.h>
#include "bbase.h"
#include "bytetape.h"
@@ -42,7 +42,7 @@ class BInt : public BBase
* @param start the position within the buffer of the beginning
* of the b-encoded integer.
*/
- BInt (QByteArray &dict, int start = 0);
+ BInt (TQByteArray &dict, int start = 0);
/**
* Constructs a BInt by reading a b-encoded integer from @p tape.
@@ -86,11 +86,11 @@ class BInt : public BBase
/**
* Outputs the b-encoded representation of the object to the given
* QIODevice.
* @param device the QIODevice to write to
* @return true on a successful write, false otherwise
*/
- virtual bool writeToDevice (QIODevice &device);
+ virtual bool writeToDevice (TQIODevice &device);
private:
@@ -86,11 +86,11 @@ class BInt : public BBase
/**
* Outputs the b-encoded representation of the object to the given
- * QIODevice.
- * @param device the QIODevice to write to
+ * TQIODevice.
+ * @param device the TQIODevice to write to
* @return true on a successful write, false otherwise
*/